@@ -340,7 +340,14 @@ gc_page_next (ExchangeAutoconfigGUI *gui)
 
 	if (result == E2K_AUTOCONFIG_OK)
 		autoconfig_gui_set_page (gui, EXCHANGE_AUTOCONFIG_PAGE_VERIFY);
-	else {
+	else if (result == E2K_AUTOCONFIG_AUTH_ERROR_TRY_DOMAIN) {
+		e_notice (gui->window, GTK_MESSAGE_ERROR,
+			  _("Could not authenticate to the Global Catalog "
+			    "server. You may need to go back and specify "
+			    "the Windows domain name as part of your "
+			    "username (eg, \"MY-DOMAIN\\%s\")."),
+			  gui->ac->username);
+	} else {
 		e_notice (gui->window, GTK_MESSAGE_ERROR,
 			  _("Could not connect to specified server.\n"
 			    "Please check the server name and try again."));
@@ -441,14 +448,25 @@ verify_page_changed (GtkEntry *entry, ExchangeAutoconfigGUI *gui)
 	autoconfig_gui_set_next_sensitive (gui, verify_page_check (gui));
 }
 
+static gboolean 
+is_active_exchange_account (EAccount *account) 
+{ 
+	if (!account->enabled) 
+		return FALSE; 
+	if (!account->source || !account->source->url) 
+		return FALSE; 
+	return (strncmp (account->source->url, "exchange://", 11) == 0); 
+}
 
 static void
 autoconfig_gui_apply (ExchangeAutoconfigGUI *gui)
 {
 	EAccountList *list;
 	EAccount *account;
+	EIterator *iter;
 	GConfClient *gconf;
 	char *pw_key;
+	gboolean found = FALSE;
 
 	/* Create the account. */
 	gconf = gconf_client_get_default ();
@@ -461,6 +479,24 @@ autoconfig_gui_apply (ExchangeAutoconfigGUI *gui)
 		return;
 	}
 
+	/* Check if any account is already configured, and throw an error if so */
+	/* NOTE: This condition check needs to be removed when we start 
+	   supporting multiple accounts */
+	for (iter = e_list_get_iterator ((EList *)list); 
+	     e_iterator_is_valid (iter); 
+	     e_iterator_next (iter)) {
+		account = (EAccount *)e_iterator_get (iter);
+		if (account && (found = is_active_exchange_account (account))) {
+			e_notice (gui->window, GTK_MESSAGE_ERROR,
+			_("You may only configure a single Exchange account"));
+			break;
+		}
+		account = NULL;
+	}
+	g_object_unref(iter);
+	if (found)
+		return;
+
 	account = e_account_new ();
 
 	account->name = g_strdup (gui->ac->email);
